@@ -21,7 +21,7 @@ config = {
     'socialusers.reserved_names': ['www', 'about', 'help', 'announcements',
         'dev', 'info', 'api', 'status', 'login', 'frontpage'],
     'cookie_age': '2592000', # 1 month
-    'server_store': ['tiddlywebplugins.mysql', {
+    'server_store': ['tiddlywebplugins.tiddlyspace.store', {
         'db_config': 'mysql:///tiddlyspace?charset=utf8&use_unicode=0'}],
     'indexer': 'tiddlywebplugins.mysql',
     'tiddlywebwiki.binary_limit': 1048576, # 1MB
