@@ -1,10 +1,13 @@
 /***
 |''Name''|TiddlySpaceMembers|
-|''Version''|0.5.2|
+|''Version''|0.5.3|
 |''Description''|provides a UI for managing space members|
 |''Status''|@@beta@@|
 |''Source''|http://github.com/TiddlySpace/tiddlyspace/raw/master/src/plugins/TiddlySpaceMembers.js|
 |''Requires''|TiddlySpaceConfig TiddlySpaceUserControls|
+!Usage
+<<TiddlySpaceMembers list>> provides list of members
+<<TiddlySpaceMembers add>> creates a form to add new members.
 !HTMLForm
 <div class='memberForm'>
 	<div class='messageArea'></div>
@@ -42,17 +45,24 @@ var macro = config.macros.TiddlySpaceMembers = {
 		var space = config.extensions.tiddlyspace.currentSpace.name;
 		var host = config.extensions.tiddlyweb.host;
 		this.space = new tiddlyweb.Space(space, host); // XXX: singleton
-		var container = $("<div />").appendTo(place);
+		var mode = params[0];
+		var container;
 		if(!readOnly) {
-			this.refresh(container);
+			if(mode == "add") {
+				macro.generateForm(place);
+			} else {
+				container = $("<div />").appendTo(place);
+				macro.refresh(container);
+			}
 		} else {
 			var msg = this.locale.authError.format([this.space.name]);
+			container = $("<div />").appendTo(place);
 			this.notify(msg, container);
 		}
 	},
 	refresh: function(container) {
 		var callback = function(data, status, xhr) {
-			container.empty();
+			$(container).empty();
 			macro.displayMembers(data, container);
 		};
 		var errback = function(xhr, error, exc) {
@@ -75,7 +85,6 @@ var macro = config.macros.TiddlySpaceMembers = {
 				return $("<li />").append(link).append(btn)[0];
 			});
 			$("<ul />").addClass("spaceMembersList").append(items).appendTo(container);
-			macro.generateForm(container);
 		});
 	},
 	generateForm: function(container) {
