@@ -3,11 +3,10 @@ http://github.com/tiddlyweb/chrjs/raw/master/main.js
 ***/
 //{{{
 // TiddlyWeb adaptor
-// v0.9.1
+// v0.9.2
 //
 // TODO:
 // * ensure all routes are supported
-// * Policy class (attributes read, write, create, delete, manage, accept and owner)
 // * documentation
 
 (function($) {
@@ -130,6 +129,7 @@ $.extend(Container.prototype, {
 	parse: function(data) {
 		var type = tiddlyweb._capitalize(this._type);
 		var container = new tiddlyweb[type](this.name, this.host);
+		data.policy = new tiddlyweb.Policy(data.policy);
 		return $.extend(container, data);
 	},
 	data: ["desc", "policy"]
@@ -249,6 +249,15 @@ $.extend(tiddlyweb.Recipe.prototype, {
 	data: ["recipe"].concat(Container.prototype.data)
 });
 
+tiddlyweb.Policy = function(constraints) { // TODO: validation?
+	var self = this;
+	$.each(this.constraints, function(i, item) {
+		self[item] = constraints[item];
+	});
+};
+tiddlyweb.Policy.prototype.constraints = ["read", "write", "create", "delete",
+	"manage", "accept", "owner"];
+
 /*
  * utilities
  */
